@@ -6,8 +6,9 @@ import (
 	appsapi "k8s.io/api/apps/v1"
 	metaapi "k8s.io/apimachinery/pkg/apis/meta/v1"
 
+	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapiv1 "github.com/openshift/api/operator/v1"
-	imageregistryv1 "github.com/openshift/cluster-image-registry-operator/pkg/apis/imageregistry/v1"
+	"github.com/openshift/cluster-image-registry-operator/defaults"
 )
 
 func updateCondition(cr *imageregistryv1.Config, condtype string, condstate operatorapiv1.OperatorCondition) {
@@ -87,10 +88,18 @@ func (c *Controller) syncStatus(cr *imageregistryv1.Config, deploy *appsapi.Depl
 		Message: "",
 		Reason:  "",
 	}
-	if deploy == nil {
+	if cr.Spec.ManagementState == operatorapiv1.Unmanaged {
+		operatorAvailable.Status = operatorapiv1.ConditionTrue
+		operatorAvailable.Message = "The registry configuration is set to unmanaged mode"
+		operatorAvailable.Reason = "Unmanaged"
+	} else if deploy == nil {
 		if e, ok := applyError.(permanentError); ok {
 			operatorAvailable.Message = applyError.Error()
 			operatorAvailable.Reason = e.Reason
+		} else if removed {
+			operatorAvailable.Status = operatorapiv1.ConditionTrue
+			operatorAvailable.Message = "The registry is removed"
+			operatorAvailable.Reason = "Removed"
 		} else {
 			operatorAvailable.Message = "The deployment does not exist"
 			operatorAvailable.Reason = "DeploymentNotFound"
@@ -159,7 +168,10 @@ func (c *Controller) syncStatus(cr *imageregistryv1.Config, deploy *appsapi.Depl
 		Message: "",
 		Reason:  "",
 	}
-	if e, ok := applyError.(permanentError); ok {
+	if cr.Spec.ManagementState == operatorapiv1.Unmanaged {
+		operatorDegraded.Message = "The registry configuration is set to unmanaged mode"
+		operatorDegraded.Reason = "Unmanaged"
+	} else if e, ok := applyError.(permanentError); ok {
 		operatorDegraded.Status = operatorapiv1.ConditionTrue
 		operatorDegraded.Message = applyError.Error()
 		operatorDegraded.Reason = e.Reason
@@ -175,7 +187,8 @@ func (c *Controller) syncStatus(cr *imageregistryv1.Config, deploy *appsapi.Depl
 	if removed {
 		operatorRemoved.Status = operatorapiv1.ConditionTrue
 		operatorRemoved.Message = "The registry is removed"
+		operatorRemoved.Reason = "Removed"
 	}
 
-	updateCondition(cr, imageregistryv1.OperatorStatusTypeRemoved, operatorRemoved)
+	updateCondition(cr, defaults.OperatorStatusTypeRemoved, operatorRemoved)
 }
