@@ -9,8 +9,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	operatorapi "github.com/openshift/api/operator/v1"
-
-	imageregistryv1 "github.com/openshift/cluster-image-registry-operator/pkg/apis/imageregistry/v1"
+	"github.com/openshift/cluster-image-registry-operator/defaults"
 )
 
 func ConditionExistsWithStatusAndReason(client *Clientset, conditionType string, conditionStatus operatorapi.ConditionStatus, conditionReason string) []error {
@@ -22,7 +21,7 @@ func ConditionExistsWithStatusAndReason(client *Clientset, conditionType string,
 		conditionExists := false
 
 		// Get a fresh version of the image registry resource
-		cr, err := client.Configs().Get(imageregistryv1.ImageRegistryResourceName, metav1.GetOptions{})
+		cr, err := client.Configs().Get(defaults.ImageRegistryResourceName, metav1.GetOptions{})
 		if err != nil {
 			if errors.IsNotFound(err) {
 				return false, nil
